# T2 Models

## T2Mono

::: qmrpy.models.t2.T2Mono
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T2EPG

::: qmrpy.models.t2.T2EPG
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T2EMC

::: qmrpy.models.t2.T2EMC
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward

## T2MultiComponent

::: qmrpy.models.t2.T2MultiComponent
    options:
      members:
        - __init__
        - fit
        - fit_image

## T2DECAESMap

::: qmrpy.models.t2.T2DECAESMap
    options:
      members:
        - __init__
        - fit
        - fit_image

## T2DECAESPart

::: qmrpy.models.t2.T2DECAESPart
    options:
      members:
        - __init__
        - fit
        - fit_image
